function [M,mesh] = angleToMatrix(mesh, RBM, angles)
%% Given the angles and RBM it constructs the chain of transformations
% Returns the motion matrices for each libm given an RBM and the joint
% angles
% 
% This function is part of the MPI08 data set, to be obtained at 
% http://www.tnt.uni-hannover.de/project/MPI08_Database/
%
% Written by: Andreas Baak (adaped code from Juergen Gall)
% Revision:   1.0
% Date:       15.07.2009
%
% Copyright 2010, MPI Informatik, Germany, and Hannover University, Germany.
% All Rights Reserved Permission to use, copy, modify, and distribute this 
% software and its documentation for any non-commercial purpose is hereby 
% granted without fee, provided that the above copyright notice appear in 
% all copies and that both that copyright notice and this permission 
% notice appear in supporting documentation, and that the name of the 
% author not be used in advertising or publicity pertaining to distribution 
% of the software without specific, written prior permission. 
% THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, 
% INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR ANY 
% PARTICULAR PURPOSE. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY 
% SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER 
% RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF 
% CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN 
% CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE. 


nodes = mesh.skel.nodes;
influencedBy = mesh.skel.influencedBy;
numNodes = numel(mesh.skel.nodes);
M = repmat({eye(4)}, numNodes, 1);
for ii = numNodes:-1:2
    Mi = angleToMatrixJoint(nodes(ii), angles(ii));
    for jj = 2:numNodes
        if influencedBy(jj,ii)
            M{jj} = Mi*M{jj};
        end
    end
end
for ii = 2:numNodes
    M{ii} = RBM*M{ii};
end
M{1} = RBM;
    function M = angleToMatrixJoint(joint, angle)
        direction = joint.direction;
        moment = cross(joint.position, joint.direction);
        omegaHat = [0 -direction(3) direction(2)
            direction(3) 0  -direction(1)
            -direction(2) direction(1)  0];
        omegaT = direction * direction';
        R = omegaHat*sin(angle) + omegaHat * omegaHat * (1-cos(angle));
        R = R + eye(3);
        T = R * (-1) + eye(3);
        t = T*cross(direction, moment) + ((omegaT*moment)*angle);
        M = zeros(4,4);
        M(1:3, 1:3) = R;
        M(1:3, 4) = t;
        M(4,4) = 1;
    end
end