function handle = drawCoordinateSystem(rotation, origin, scale, h_AX, LineWidth,LineStyle,axis)
% Simply draws a coordinate system.
% INPUT:
%   rotation: 3x3 rotation matrix
%   origin  : 3x1 vector pointing to the origin of the coordinate system
%   scale   : length of the axes to draw
%   h_AX    : matlab figure axis to draw into
%  LineWidth: matlab line width parameter
%  LineStyle: matlab line style parameter
%     axis  : leave out to draw x,y, and z axis. Can be 'x', to draw only
%             the x-axis, 'y', to draw only the 'y'-axis, and 'z', to draw
%             only the z-axis.
%
% This function is part of the MPI08 data set, to be obtained at 
% http://www.tnt.uni-hannover.de/project/MPI08_Database/
%
%
% Written by: Andreas Baak 
% Revision:   1.0
% Date:       15.07.2009
%
% Copyright 2010, MPI Informatik, Germany, and Hannover University, Germany.
% All Rights Reserved Permission to use, copy, modify, and distribute this 
% software and its documentation for any non-commercial purpose is hereby 
% granted without fee, provided that the above copyright notice appear in 
% all copies and that both that copyright notice and this permission 
% notice appear in supporting documentation, and that the name of the 
% author not be used in advertising or publicity pertaining to distribution 
% of the software without specific, written prior permission. 
% THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, 
% INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR ANY 
% PARTICULAR PURPOSE. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY 
% SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER 
% RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF 
% CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN 
% CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE. 
if ~exist('origin', 'var')
    origin = [0;0;0];
end
if ~exist('scale', 'var')
    scale = 1;
end
if ~exist('h_AX', 'var')
    h_AX=gca;
end
if ~exist('LineWidth', 'var')
    LineWidth=1.5;
end
if ~exist('LineStyle', 'var')
    LineStyle= '-';
end
if all(size(rotation) == [4,1])
    rotation = quat2matrix(rotation);
elseif all(size(rotation) == [3,3])
    % ok
else
    error('Not recognized rotation representation');
end

if ~exist('axis', 'var')
    handle = zeros(1,3);
    % x axis
    handle(1) = plot3(h_AX,[origin(1) origin(1)+scale*rotation(1, 1)],...
        [origin(2) origin(2)+scale*rotation(2, 1)],...
        [origin(3) origin(3)+scale*rotation(3, 1)], 'linewidth', LineWidth, 'color', [1 0 0 ],'linestyle',LineStyle);
    hold on
    % y axis
    
    handle(2) = plot3(h_AX,[origin(1) origin(1)+scale*rotation(1, 2)],...
        [origin(2) origin(2)+scale*rotation(2, 2)],...
        [origin(3) origin(3)+scale*rotation(3, 2)], 'linewidth',LineWidth , 'color', [0 1 0 ],'linestyle',LineStyle);
    
    % z axis
    
    handle(3) = plot3(h_AX,[origin(1) origin(1)+scale*rotation(1, 3)],...
        [origin(2) origin(2)+scale*rotation(2, 3)],...
        [origin(3) origin(3)+scale*rotation(3, 3)], 'linewidth', LineWidth, 'color', [0 0 1 ],'linestyle',LineStyle);
else
    switch axis
        case 'x'
            % x axis
            handle(1) = plot([origin(1) origin(1)+scale*rotation(1, 1)],...
                [origin(2) origin(2)+scale*rotation(2, 1)],...
                [origin(3) origin(3)+scale*rotation(3, 1)], 'linewidth', LineWidth, 'color', [1 0 0 ],'linestyle',LineStyle);
        case'y'
            % y axis
            handle(2) = plot([origin(1) origin(1)+scale*rotation(1, 2)],...
                [origin(2) origin(2)+scale*rotation(2, 2)],...
                [origin(3) origin(3)+scale*rotation(3, 2)], 'linewidth', LineWidth, 'color', [0 1 0 ],'linestyle',LineStyle);
            
        case 'z'
            % z axis
            handle(3) = plot([origin(1) origin(1)+scale*rotation(1, 3)],...
                [origin(2) origin(2)+scale*rotation(2, 3)],...
                [origin(3) origin(3)+scale*rotation(3, 3)], 'linewidth', LineWidth, 'color', [0 0 1 ],'linestyle',LineStyle);
    end
end
%set(h_AX,'Children',handle);
end
