function [skelVertices, skelFaces] = generateSkeletonPatch(nodes)
% based on a set of nodes, a path will be generated that can be used to
% draw the skeleton.
% INPUT:
%  nodes struct containing the fields
%     children
%     position
% OUTPUT:
%  vertices (MxN) M=3; or M=2
%  faces    (MxF)
%
% This function is part of the MPI08 data set, to be obtained at 
% http://www.tnt.uni-hannover.de/project/MPI08_Database/
%
% Written by: Andreas Baak
% Revision:   1.0
% Date:       15.07.2009
%
% Copyright 2010, MPI Informatik, Germany, and Hannover University, Germany.
% All Rights Reserved Permission to use, copy, modify, and distribute this
% software and its documentation for any non-commercial purpose is hereby
% granted without fee, provided that the above copyright notice appear in
% all copies and that both that copyright notice and this permission
% notice appear in supporting documentation, and that the name of the
% author not be used in advertising or publicity pertaining to distribution
% of the software without specific, written prior permission.
% THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
% INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR ANY
% PARTICULAR PURPOSE. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
% SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
% RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF
% CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
% CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.


M=numel(nodes(1).position);
numChildren = numel([nodes.children]);
skelVertices = zeros(M, numChildren*2);
skelFaces = bsxfun(@plus, [ 0; 1; 1;], (1:numChildren)*2-1); % bsxfun automatically expands the missing dimensions by repeating data.

vCtr = 1;

for i=1:numel(nodes)
    nodePos = nodes(i).position;
    ch = nodes(i).children;
    for c=1:numel(ch)
        cIdx = ch(c);
        skelVertices(:, vCtr + [0 1]) = [nodePos nodes(cIdx).position];
        vCtr = vCtr + 2;
    end
end
end